Customizer class

Constructors

Customizer({String cameraSource = 'Camera', String gallerySource = 'Gallery', String replyPlaceholder = 'Message...', String slideToSee = 'Slide to see...', String seconds = 's', String minutes = 'm', String hours = 'h', String days = 'd', String weeks = 'w', IconData closeIcon = Icons.close, IconData infoIcon = Icons.more_horiz, IconData failedImageIcon = Icons.broken_image, IconData sendIcon = Icons.send, IconData gallerySourceIcon = Icons.image, IconData cameraSourceIcon = Icons.camera_alt})

Properties

cameraSource → String
final
cameraSourceIcon → IconData
final
closeIcon → IconData
final
days → String
final
failedImageIcon → IconData
final
gallerySource → String
final
gallerySourceIcon → IconData
final
hashCode → int
The hash code for this object.
no setterinherited
hours → String
final
infoIcon → IconData
final
minutes → String
final
replyPlaceholder → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seconds → String
final
sendIcon → IconData
final
slideToSee → String
final
weeks → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited