StoryViewer class

Inheritance

Constructors

StoryViewer({Key? key, StoryViewerController? viewerController, UserModel? userModel, List<StoryItemModel>? stories, bool fromAnonymous = false, bool trusted = true, int initIndex = 0, dynamic onEachStoryLoadComplated({String storyID})?, dynamic onEditStory({StoryViewer? viewer, StoryViewerController? viewerController})?, Function? onDispose, String? heroTag, dynamic onStoryReplied({String? message, String? storyID, StoryViewerController? viewerController})?, dynamic onUserTap({StoryViewerController? viewerController})?, Widget? profilePicture, Customizer? customValues, List<Widget> getAdditionalLayersBeforeMedia({StoryViewer viewer, StoryViewerController viewerController})?, List<Widget> getAdditionalLayersAfterMedia({StoryViewer viewer, StoryViewerController viewerController})?, String? displayerUserID, Alignment? mediaAlignment, BoxFit? mediaFit, Color? backgroundColor, Color? placeholderBackground, List<Color>? placeholderBackgrounds, SystemUiOverlayStyle? systemOverlayStyle, Duration? serverTimeGap, bool willPop()?, bool hasReply = false, bool showSource = false, EdgeInsets? progressRowPadding, BorderRadius progressBorderRadius = BorderRadius.zero, Color progressColor = Colors.white, BorderRadiusGeometry? borderRadius, double progressHeight = 4, TextStyle? titleStyle, void setupCustomWidgets({StoryViewer viewer, StoryViewerController? viewerController})?, EdgeInsets padding = EdgeInsets.zero, StoryRatio ratio = StoryRatio.r9_16, bool loop = false, String? profileHeroTag})
const

Properties

backgroundColor → Color?
final
borderRadius → BorderRadiusGeometry?
final
customizer → Customizer
no setter
customValues → Customizer?
final
displayerUserID → String?
final
fromAnonymous → bool
final
getAdditionalLayersAfterMedia → List<Widget> Function({StoryViewer viewer, StoryViewerController viewerController})?
final
getAdditionalLayersBeforeMedia → List<Widget> Function({StoryViewer viewer, StoryViewerController viewerController})?
final
hashCode → int
The hash code for this object.
no setterinherited
hasReply → bool
final
heroTag → String?
final
initIndex → int
final
inline → bool
no setter
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loop → bool
final
mediaAlignment → Alignment?
final
mediaFit → BoxFit?
final
onDispose → Function?
final
onEachStoryLoadComplated → dynamic Function({String storyID})?
final
onEditStory → dynamic Function({StoryViewer? viewer, StoryViewerController? viewerController})?
final
onStoryReplied → dynamic Function({String? message, String? storyID, StoryViewerController? viewerController})?
final
onUserTap → dynamic Function({StoryViewerController? viewerController})?
final
padding → EdgeInsets
final
placeholderBackground → Color?
final
placeholderBackgrounds → List<Color>?
final
profileHeroTag → String?
final
profilePicture → Widget?
final
progressBorderRadius → BorderRadius
final
progressColor → Color
final
progressHeight → double
final
progressRowPadding → EdgeInsets?
final
ratio → StoryRatio
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverTimeGap → Duration?
final
setupCustomWidgets → void Function({StoryViewer viewer, StoryViewerController? viewerController})?
final
showSource → bool
final
stories → List<StoryItemModel>?
final
systemOverlayStyle → SystemUiOverlayStyle?
final
titleStyle → TextStyle?
final
trusted → bool
final
userModel → UserModel?
final
viewerController → StoryViewerController?
final
willPop → bool Function()?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _StoryViewerState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pop(BuildContext context) → Future<bool>
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited