StoryViewerController class

Constructors

StoryViewerController({int? currentIndex = 0})

Properties

animationController ↔ AnimationController
getter/setter pair
currentHeroTag → String
no setter
currentIndex ↔ int?
getter/setter pair
currentStory → StoryItemModel
no setter
hashCode → int
The hash code for this object.
no setterinherited
heroTag → String
no setter
isPlaying → bool
no setter
nexter ↔ Timer?
getter/setter pair
owner → bool
no setter
ownerUserID → String
no setter
prevShadower ↔ Timer?
getter/setter pair
replying → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stories → List<StoryItemModel>
no setter
trusted ↔ bool?
getter/setter pair
uiHider ↔ Timer?
getter/setter pair
uiHiding → bool
no setter
viewer ↔ StoryViewer?
getter/setter pair

Methods

addListener({Function? onPlayed, Function? onPaused, Function? onIndexChanged, Function? onComplated, Function? onPrewShadowShow, Function? onPrewShadowHide, Function? onUIShow, Function? onUIHide}) → void
cancelHider() → void
changeIndex({int? newIndex}) → void
complated() → void
elementPause() → void
handPause({bool prewShadowShow = false}) → void
handPlay({bool prewStory = false}) → void
infoPause() → void
infoPlay() → void
isLoaded(ImageProvider<Object> provider) → bool?
load(ImageProvider<Object>? provider) → void
next() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → void
play() → void
previous() → void
replyPause() → void
replyPlay() → void
statusListener(dynamic status) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited